==> hermes-6.0.2.8.tar.gz: hermes-6.0.2.8/app/services/batch_tasks/new_published_offer_notification.rb <==
module BatchTasks
  class NewPublishedOfferNotification < Base
    
    MAX_OFFER_PER_NOTIFICATION = 6

    def generate_and_enqueue_notification(date_start: DateTime.now - 1.days, date_end:  DateTime.now, tagset_id: nil, offer_filter: {})
      starttime = Time.now
      @log_name = "#{print_time(starttime)}_new_published_offers_from_#{print_time(date_start)}_to_#{print_time(date_end)}.log"

      offer_ids = Hermes::HousingOffer.where(offer_filter.merge(
        reserved: false,
        offer_status: "LOGEMENT PUBLIE",
        lessor_status: "PUBLIE",
        date_publication_start: { :$gte => date_start, :$lte => date_end }
      )).order_by(date_publication_start: :desc).pluck(:id)
      add_to_log_file("#{offer_ids.length} offers found")
      
      notif_hash = generate_notif_hash(offer_ids)
      notification_nb = enqueue_notifications(notif_hash, :new_published_offer)
    
      add_to_log_file("Generated #{notification_nb} notifications in #{(Time.now - starttime).seconds.round(2)}")
    
      create_log_doc(tagset_id)
    end 
    
    private

    def generate_notif_hash(offer_ids)
      notif_hash =  {}

      [
        'seeked',
        'bordering',
        'other_from_department',
      ].each do |type|
        offer_ids.each_slice(1000) do |offer_ids|
          Hermes::HousingOffer.where(:id.in => offer_ids).each do |offer|
            begin
              eligible_request_ids = offer.eligibles_requests(type).where(active_application_id: nil).pluck(:id)
              add_to_log_file("Found #{eligible_request_ids.length} eligible requests for offer #{offer.id}")
    
              eligible_request_ids.each do |request_id|
                notif_hash[request_id] ||= []
                notif_hash[request_id] << offer.id.to_s if notif_hash[request_id].length < MAX_OFFER_PER_NOTIFICATION
              end
            rescue => exception
              add_to_log_file("housing_offer_id : #{offer.id} => #{exception}")
            end
          end
        end
      end
    
      notif_hash
    end 
  end
end

==> hermes-6.0.2.24.tar.gz: hermes-6.0.2.24/app/services/batch_tasks/new_published_offer_notification.rb <==
module BatchTasks
  class NewPublishedOfferNotification < Base
    
    MAX_OFFER_PER_NOTIFICATION = 6

    def generate_and_enqueue_notification(date_start: DateTime.now - 1.days, date_end:  DateTime.now, tagset_id: nil, offer_filter: {})
      starttime = Time.now
      @log_name = "#{print_time(starttime)}_new_published_offers_from_#{print_time(date_start)}_to_#{print_time(date_end)}.log"

      offer_ids = Hermes::HousingOffer.where(offer_filter.merge(
        reserved: false,
        offer_status: "LOGEMENT PUBLIE",
        lessor_status: "PUBLIE",
        date_publication_start: { :$gte => date_start, :$lte => date_end }
      )).order_by(date_publication_start: :desc).pluck(:id)
      add_to_log_file("#{offer_ids.length} offers found")
      
      notif_hash = generate_notif_hash(offer_ids)
      notification_nb = enqueue_notifications(notif_hash, :new_published_offer)
    
      add_to_log_file("Generated #{notification_nb} notifications in #{(Time.now - starttime).seconds.round(2)}")
    
      create_log_doc(tagset_id)
    end 
    
    private

    def generate_notif_hash(offer_ids)
      notif_hash =  {}

      [
        'seeked',
        'bordering',
        'other_from_department',
      ].each do |type|
        offer_ids.each_slice(1000) do |offer_ids|
          Hermes::HousingOffer.where(:id.in => offer_ids).each do |offer|
            begin
              eligible_request_ids = offer.eligibles_requests(type).where(active_application_id: nil).pluck(:id)
              add_to_log_file("Found #{eligible_request_ids.length} #{type} eligible requests for offer #{offer.id}")
    
              eligible_request_ids.each do |request_id|
                notif_hash[request_id] ||= []
                notif_hash[request_id] << offer.id.to_s if notif_hash[request_id].length < MAX_OFFER_PER_NOTIFICATION
              end
            rescue => exception
              add_to_log_file("housing_offer_id : #{offer.id} => #{exception}")
            end
          end
        end
      end
    
      notif_hash
    end 
  end
end
